<template>
  <!-- 状态日志弹窗 -->
  <div>
    <el-dialog
      :title="`${title}状态日志`"
      :visible="visible"
      v-if="visible"
      :before-close="handleClose"
      custom-class="bbsl-location-dialog"
      width="70%"
    >
      <div>
        <el-form
          class="bbsl-scroll-form-spare"
          ref="formInfo"
          :rules="rules"
          :model="params"
          label-width="150px"
        >
          <el-collapse
            accordion
            v-model="activeCollapse1"
            class="form-collapse"
          >
            <el-collapse-item name="1">
              <template slot="title">
                <span class="collapse-title">
                  <i class="collapse-title-icon el-icon-info"></i>
                  基础信息
                </span>
              </template>
              <el-row>
                <el-col :span="12">
                  <el-form-item label="设备标识：" prop="deviceCode">
                    <el-input
                      clearable
                      :disabled="true"
                      placeholder="请输入设备标识 "
                      v-model="params.deviceCode"
                    ></el-input>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item label="设备名称：" prop="deviceName">
                    <el-input
                      clearable
                      :disabled="true"
                      placeholder="请输入设备名称"
                      v-model="params.deviceName"
                    ></el-input>
                  </el-form-item>
                </el-col>
              </el-row>
              <el-row>
                <el-col :span="12">
                  <el-form-item label="状态开始时间：" prop="startTime">
                    <el-date-picker
                      clearable
                      type="datetime"
                      popper-class="dataTime-style"
                      value-format="yyyy-MM-dd HH:mm:ss"
                      style="width:100%"
                      placeholder="请选择状态开始时间"
                      v-model="params.startTime"
                    ></el-date-picker>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item
                    inline="true"
                    label="状态结束时间："
                    prop="endTime"
                  >
                    <el-date-picker
                      clearable
                      type="datetime"
                      popper-class="dataTime-style"
                      value-format="yyyy-MM-dd HH:mm:ss"
                      v-model="params.endTime"
                      placeholder="请选择状态结束时间"
                      style="width:100%"
                    ></el-date-picker>
                  </el-form-item>
                </el-col>
              </el-row>
              <el-row>
                <el-col :span="12">
                  <el-form-item label="状态时长 (分钟)：" prop="timeLength">
                    <el-input
                      clearable
                      type="number"
                      placeholder="请输入状态时长 (分钟)"
                      v-model="params.timeLength"
                    ></el-input>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item label="设备状态：" prop="deviceStatus">
                    <el-select
                      clearable
                      style="width: 100%"
                      v-model="params.deviceStatus"
                      placeholder="请选择设备状态"
                    >
                      <el-option
                        v-for="item in deviceStatusList"
                        :key="item.value"
                        :label="item.name"
                        :value="item.value"
                      ></el-option
                      >
                    </el-select>
                  </el-form-item>
                </el-col>
              </el-row>
            </el-collapse-item>
          </el-collapse>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleSave">保存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import dictUtils from '@/components/dict/DictSelectUtils.js'
import equipmentManage from '@/api/device/equipmentManage.js'
import utils from '@/hotent-ui-util.js'

export default {
  name: 'EquipStatuslogDialog',
  data() {
    return {
      //显示
      visible: false,
      title: '新增',
      params: {
        deviceCode: '', //设备编码
        deviceName: '', //设备名称
        deviceStatus: '', //设备状态
        endTime: '', //状态结束时间
        startTime: '', //状态开始时间
        timeLength: 0 //状态时长 (分钟)
      },
      deviceStatusList: [], //设备状态字段列表
      activeCollapse1: '1',
      rules: {
        // deviceCode: [
        //   {
        //     required: true,
        //     message: '请输入设备标识',
        //     trigger: 'blur'
        //   }
        // ],
        // deviceName: [
        //   {
        //     required: true,
        //     message: '请输入设备名称',
        //     trigger: 'blur'
        //   }
        // ],
        deviceStatus: [
          {
            required: true,
            message: '请选择设备状态',
            trigger: 'change'
          }
        ],
        endTime: [
          {
            required: true,
            message: '请选择状态结束时间',
            trigger: 'change'
          }
        ],
        startTime: [
          {
            required: true,
            message: '请选择状态开始时间',
            trigger: 'change'
          }
        ],
        timeLength: [
          {
            required: true,
            message: '请输入状态时长（分钟）',
            trigger: 'change'
          }
        ]
      }
    }
  },
  created() {
    this.deviceStatusList = dictUtils.getDictItemsFromCache('sbzt')
  },
  mounted() {
  },
  methods: {
    add(userRow) {
      this.params.deviceCode = userRow.code
      this.params.deviceName = userRow.name
      this.visible = true
    },
    // 保存产品信息
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          if (this.title === '新增') {
            equipmentManage.addLog(this.params, res => {
              console.log(this.params)
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '新增成功',
                  duration: 2000
                })
                this.handleClose()
                this.$parent.loadData(1)
              } else {
              }
            })
          }
          if (this.title === '修改') {
            equipmentManage.updateLog(this.params, res => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '修改成功',
                  duration: 2000
                })
                this.handleClose()
                this.$parent.loadData(1)
              } else {
              }
            })
          }
        } else {
          return false
        }
      })
    },
    edit(row) {
      this.visible = true
      this.title = '修改'
      equipmentManage.findLogById(row.id, res => {
        this.params = res
        this.params.deviceName = row.deviceName
      })
    },
    // 关闭新增人员窗口
    handleClose() {
      this.params = {
        deviceCode: '', //设备编码
        deviceName: '', //设备名称
        deviceStatus: '', //设备状态
        endTime: '', //状态结束时间
        startTime: '', //状态开始时间
        timeLength: 0 //状态时长 (分钟)
      }
      this.title = '新增'
      this.visible = false
      this.activeCollapse1 = '1'
    }
  }
}
</script>

<style lang="scss" scoped>
.bbsl-scroll-form-spare {
  width: calc(100% - 20px);
  height: calc(95vh - 500px);
  overflow-y: auto;
  padding: 0 10px;
}

.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}

.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}

.column-box {
  color: #409eff;
  display: flex;
  justify-content: space-evenly;
}

</style>
<style lang="scss">
.dataTime-style {
  .el-time-spinner__item {
    height: auto !important;
    line-height: inherit;
  }

  .el-scrollbar__wrap {
    overflow: scroll !important;
  }
}
</style>
